@@ -1089,13 +1089,13 @@ def parse_command_line_arguments():
                              "please make sure your path ends with a '/'. Otherwise the program will assume the last "
                              "string after the final '/' as the name of the report file. A single report file will be "
                              "generated. Information for each species will be put into individual worksheets.")
-    parser.add_argument('--histogram', '-hist',
-                        help="Set this option to 1 if you wish to view the histogram of GO_TERM frequency before and "
-                             "after debiasing is performed with respect to cutoffs based on number of proteins or "
-                             "annotations. If you wish to save the file then please enter a filepath. If you are "
-                             "providing a path please make sure your path ends with a '/'. Otherwise the program will "
-                             "assume the last string after the final '/' as the name of the image file. Separate "
-                             "histograms will be generated for each species.")
+    # parser.add_argument('--histogram', '-hist',
+    #                    help="Set this option to 1 if you wish to view the histogram of GO_TERM frequency before and "
+    #                         "after debiasing is performed with respect to cutoffs based on number of proteins or "
+    #                         "annotations. If you wish to save the file then please enter a filepath. If you are "
+    #                         "providing a path please make sure your path ends with a '/'. Otherwise the program will "
+    #                         "assume the last string after the final '/' as the name of the image file. Separate "
+    #                         "histograms will be generated for each species.")
 
     args = parser.parse_args()
     return args
